aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/phpbb/lock/db.php
diff options
context:
space:
mode:
Diffstat (limited to 'phpBB/phpbb/lock/db.php')
-rw-r--r--phpBB/phpbb/lock/db.php21
1 files changed, 12 insertions, 9 deletions
diff --git a/phpBB/phpbb/lock/db.php b/phpBB/phpbb/lock/db.php
index 461adda045..85ba9a7aa3 100644
--- a/phpBB/phpbb/lock/db.php
+++ b/phpBB/phpbb/lock/db.php
@@ -1,9 +1,13 @@
<?php
/**
*
-* @package phpBB3
-* @copyright (c) 2010 phpBB Group
-* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
+* This file is part of the phpBB Forum Software package.
+*
+* @copyright (c) phpBB Limited <https://www.phpbb.com>
+* @license GNU General Public License, version 2 (GPL-2.0)
+*
+* For full copyright and license information, please see
+* the docs/CREDITS.txt file.
*
*/
@@ -11,7 +15,6 @@ namespace phpbb\lock;
/**
* Database locking class
-* @package phpBB3
*/
class db
{
@@ -42,7 +45,7 @@ class db
/**
* A database connection
- * @var \phpbb\db\driver\driver
+ * @var \phpbb\db\driver\driver_interface
*/
private $db;
@@ -51,11 +54,11 @@ class db
*
* You have to call acquire() to actually create the lock.
*
* @param string $config_name A config variable to be used for locking
* @param array $config The phpBB configuration
* @param \phpbb\db\driver\driver $db A database connection
*/
- public function __construct($config_name, \phpbb\config\config $config, \phpbb\db\driver\driver $db)
+ public function __construct($config_name, \phpbb\config\config $config, \phpbb\db\driver\driver_interface $db)
{
$this->config_name = $config_name;
$this->config = $config;
@@ -51,11 +54,11 @@ class db
* You have to call acquire() to actually create the lock.
*
- * @param string $config_name A config variable to be used for locking
- * @param array $config The phpBB configuration
- * @param \phpbb\db\driver\driver $db A database connection
+ * @param string $config_name A config variable to be used for locking
+ * @param \phpbb\config\config $config The phpBB configuration
+ * @param \phpbb\db\driver\driver_interface $db A database connection
*/